"use strict";
/**
 * SPDX-FileCopyrightText: © 2017 Liferay, Inc. <https://liferay.com>
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSupportedLocales = exports.getWebpackProxy = exports.getWebpackPort = exports.getWebpackExtensions = exports.getWebpackRules = exports.getWebpackMainModule = exports.getTranslatorTextKey = exports.getLiferayDir = exports.project = void 0;
const js_toolkit_core_1 = require("@liferay/js-toolkit-core");
const dot_prop_1 = __importDefault(require("dot-prop"));
const read_json_sync_1 = __importDefault(require("read-json-sync"));
exports.project = new js_toolkit_core_1.Project('.');
// eslint-disable-next-line @typescript-eslint/no-explicit-any
let npmbuildrc = {};
// eslint-disable-next-line @typescript-eslint/no-explicit-any
let configuration = {};
loadConfig();
/**
 * Load project configuration
 */
function loadConfig() {
    npmbuildrc = safeReadJsonSync(exports.project.dir.join('.npmbuildrc').asNative);
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    configuration = exports.project._configuration;
    // Normalize configurations
    normalize(npmbuildrc, 'supportedLocales', []);
    normalize(npmbuildrc, 'webpack.mainModule', 'index.js');
    normalize(npmbuildrc, 'webpack.rules', []);
    normalize(npmbuildrc, 'webpack.extensions', ['.js']);
    normalize(npmbuildrc, 'webpack.port', null);
    normalize(npmbuildrc, 'webpack.proxy', {});
    normalize(configuration, 'create-jar.features.localization', 'features/localization/Language');
}
/**
 * Get the path to the local installation of Liferay (if any).
 * @return {string|undefined}
 */
function getLiferayDir() {
    return npmbuildrc.liferayDir;
}
exports.getLiferayDir = getLiferayDir;
/**
 * Get the Microsoft Translator credentials
 * @return {string|undefined}
 */
function getTranslatorTextKey() {
    return npmbuildrc.translatorTextKey;
}
exports.getTranslatorTextKey = getTranslatorTextKey;
/**
 * Get the main module path to be used when building with webpack.
 * @return {string}
 */
function getWebpackMainModule() {
    return npmbuildrc.webpack.mainModule;
}
exports.getWebpackMainModule = getWebpackMainModule;
/**
 * Get the webpack rules to use.
 * @return {Array}
 */
function getWebpackRules() {
    return npmbuildrc.webpack.rules;
}
exports.getWebpackRules = getWebpackRules;
/**
 * Get the webpack extensions to use.
 * @return {Object}
 */
function getWebpackExtensions() {
    return npmbuildrc.webpack.extensions;
}
exports.getWebpackExtensions = getWebpackExtensions;
/**
 * Get the webpack port to use.
 * @return {number}
 */
function getWebpackPort() {
    return npmbuildrc.webpack.port;
}
exports.getWebpackPort = getWebpackPort;
/**
 * Get the webpack proxy to use.
 * @return {Object}
 */
function getWebpackProxy() {
    return npmbuildrc.webpack.proxy;
}
exports.getWebpackProxy = getWebpackProxy;
/**
 * Get the list of supported locales
 * @return {Array<string>}
 */
function getSupportedLocales() {
    return npmbuildrc.supportedLocales;
}
exports.getSupportedLocales = getSupportedLocales;
/**
 * Set a property in a configuration object if it doesn't exist
 * @param {object} cfg
 * @param {string} propPath
 * @param {*} value
 */
function normalize(cfg, propPath, value) {
    if (!dot_prop_1.default.has(cfg, propPath)) {
        dot_prop_1.default.set(cfg, propPath, value);
    }
}
/**
 * Read a JSON file without failure if it doesn't exist.
 * @param {string} path
 * @return {object}
 */
function safeReadJsonSync(path) {
    try {
        return read_json_sync_1.default(path);
    }
    catch (err) {
        if (err.code !== 'ENOENT') {
            throw err;
        }
    }
}
