"use strict";
/**
 * SPDX-FileCopyrightText: © 2017 Liferay, Inc. <https://liferay.com>
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const js_toolkit_core_1 = require("@liferay/js-toolkit-core");
const build_1 = __importDefault(require("./scripts/build"));
const copy_assets_1 = __importDefault(require("./scripts/copy-assets"));
const copy_sources_1 = __importDefault(require("./scripts/copy-sources"));
const create_jar_1 = __importDefault(require("./scripts/create-jar"));
const deploy_1 = __importDefault(require("./scripts/deploy"));
const start_1 = __importDefault(require("./scripts/start"));
const translate_1 = __importDefault(require("./scripts/translate"));
const { error, info, print } = js_toolkit_core_1.format;
const COMMANDS = {
    build: {
        description: 'generate bundled files in build folder',
        scriptFunction: build_1.default,
    },
    'copy-assets': {
        description: 'copy files from assets to build folder',
        scriptFunction: copy_assets_1.default,
    },
    'copy-sources': {
        description: 'copy static files from source to build folder',
        scriptFunction: copy_sources_1.default,
    },
    'create-jar': {
        description: 'create a JAR file from bundled files',
        scriptFunction: create_jar_1.default,
    },
    deploy: {
        description: 'deploy JAR file to local Liferay server',
        scriptFunction: deploy_1.default,
    },
    start: {
        description: 'start webpack devserver (deprecated)',
        scriptFunction: start_1.default,
    },
    translate: {
        description: 'pass project labels through Microsoft Translator',
        scriptFunction: translate_1.default,
    },
};
async function main() {
    const scripts = process.argv.slice(2);
    if (scripts.length === 0) {
        print(error `No scripts to run were specified`);
        showUsage();
        process.exit(1);
    }
    const unknownScripts = scripts.filter((script) => !COMMANDS[script]);
    if (unknownScripts.length > 0) {
        print(error `Unknown scripts found: ${unknownScripts.join(', ')}'`);
        showUsage();
        process.exit(1);
    }
    for (const script of scripts) {
        try {
            const { scriptFunction } = COMMANDS[script];
            await scriptFunction();
        }
        catch (err) {
            print(error `Script 'js-toolkit ${script}' failed:\n${err.stack}`);
            process.exit(1);
        }
    }
}
exports.default = main;
function showUsage() {
    print('', info `
			Supported scripts are:
			${Object.entries(COMMANDS)
        .map(([id, { description }]) => `    {${id}}: ${description}`)
        .join('\n')}
		`);
}
