"use strict";
/**
 * SPDX-FileCopyrightText: © 2017 Liferay, Inc. <https://liferay.com>
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const js_toolkit_core_1 = require("@liferay/js-toolkit-core");
const fs_extra_1 = __importDefault(require("fs-extra"));
const globby_1 = __importDefault(require("globby"));
const jszip_1 = __importDefault(require("jszip"));
const path_1 = __importDefault(require("path"));
const config_1 = require("../../config");
const ddm = __importStar(require("./ddm"));
const xml = __importStar(require("./xml"));
const { print, success } = js_toolkit_core_1.format;
const { pkgJson } = config_1.project;
/**
 * Create an OSGi bundle with build's output
 */
async function createJar() {
    const zip = new jszip_1.default();
    addManifest(zip);
    addBuildFiles(zip);
    addLocalizationFiles(zip);
    addConfigurationJsonSystemFiles(zip);
    addConfigurationJsonPortletInstanceFile(zip);
    const buffer = await zip.generateAsync({ type: 'nodebuffer' });
    const outputDir = config_1.project.jar.outputDir;
    fs_extra_1.default.mkdirpSync(outputDir.asNative);
    fs_extra_1.default.writeFileSync(outputDir.join(config_1.project.jar.outputFilename).asNative, buffer);
    const jarFilePath = config_1.project.dir.relative(outputDir.join(config_1.project.jar.outputFilename)).asNative;
    print(success `File {${jarFilePath}} created`);
}
exports.default = createJar;
/**
 * Add build's output files to ZIP archive
 */
function addBuildFiles(zip) {
    addFiles(config_1.project.outputDir.asNative, ['**/*', `!${config_1.project.jar.outputFilename}`], zip.folder('META-INF').folder('resources'));
}
/**
 * Add several files to a ZIP folder.
 * @param srcDirPath source folder
 * @param srcGlobs
 * array of globs describing files to include (in globby, i.e. POSIX, format)
 * @param destFolder the destination folder in the ZIP file
 */
function addFiles(srcDirPath, srcGlobs, destFolder) {
    const filePaths = globby_1.default
        .sync(srcGlobs, {
        cwd: srcDirPath,
        nodir: true,
    })
        .map((posixPath) => new js_toolkit_core_1.FilePath(posixPath, { posix: true }))
        .map((file) => file.asNative);
    filePaths.forEach((filePath) => {
        const parts = filePath.split(path_1.default.sep);
        const dirs = parts.slice(0, parts.length - 1);
        const name = parts[parts.length - 1];
        const folder = dirs.reduce((folder, dir) => folder.folder(dir), destFolder);
        folder.file(name, fs_extra_1.default.readFileSync(path_1.default.join(srcDirPath, filePath)));
    });
}
/**
 * Add the localization bundle files if configured.
 */
function addLocalizationFiles(zip) {
    const languageFileBaseName = config_1.project.l10n.languageFileBaseName;
    if (languageFileBaseName) {
        const localizationDirPath = path_1.default.dirname(languageFileBaseName.asNative);
        addFiles(localizationDirPath, ['**/*'], zip.folder('content'));
    }
}
/**
 * Add the manifest file to the ZIP archive
 */
function addManifest(zip) {
    let contents = '';
    const bundlerVersion = config_1.project.versionsInfo.get('liferay-npm-bundler')
        .version;
    contents += `Manifest-Version: 1.0\n`;
    contents += `Bundle-ManifestVersion: 2\n`;
    contents += `Tool: liferay-npm-bundler-${bundlerVersion}\n`;
    contents += `Bundle-SymbolicName: ${pkgJson.name}\n`;
    contents += `Bundle-Version: ${pkgJson.version}\n`;
    if (pkgJson.description) {
        contents += `Bundle-Name: ${pkgJson.description}\n`;
    }
    contents += `Web-ContextPath: ${config_1.project.jar.webContextPath}\n`;
    contents +=
        `Provide-Capability: osgi.webresource;` +
            `osgi.webresource=${pkgJson.name};` +
            `version:Version="${pkgJson.version}"\n`;
    if (config_1.project.l10n.supported) {
        const bundleName = path_1.default.basename(config_1.project.l10n.languageFileBaseName.asNative);
        contents += `Provide-Capability: liferay.resource.bundle;`;
        contents += `resource.bundle.base.name="content.${bundleName}"\n`;
    }
    if (config_1.project.jar.requireJsExtender) {
        let filter;
        const minimumExtenderVersion = getMinimumExtenderVersion();
        if (minimumExtenderVersion) {
            filter =
                `(&` +
                    `(osgi.extender=liferay.frontend.js.portlet)` +
                    `(version>=${minimumExtenderVersion})` +
                    `)`;
        }
        else {
            filter = `(osgi.extender=liferay.frontend.js.portlet)`;
        }
        contents += `Require-Capability: osgi.extender;filter:="${filter}"\n`;
    }
    Object.entries(config_1.project.jar.customManifestHeaders).forEach(([key, value]) => {
        contents += `${key}: ${value}\n`;
    });
    zip.folder('META-INF').file('MANIFEST.MF', contents);
}
/**
 * Add the settings files if configured.
 */
function addConfigurationJsonSystemFiles(zip) {
    const systemConfigJson = getConfigurationJsonSystemJson();
    if (!systemConfigJson) {
        return;
    }
    // Add OSGI-INF/metatype/metatype.xml file
    const localization = config_1.project.l10n.supported
        ? `content/${path_1.default.basename(config_1.project.l10n.languageFileBaseName.asNative)}`
        : undefined;
    const name = systemConfigJson.name ||
        (localization ? pkgJson.name : pkgJson.description || pkgJson.name);
    const metatype = xml.createMetatype(pkgJson.name, name);
    if (localization) {
        xml.addMetatypeLocalization(metatype, localization);
    }
    const fields = Object.entries(systemConfigJson.fields);
    fields.forEach(([id, desc]) => {
        xml.addMetatypeAttr(metatype, id, desc);
    });
    zip.folder('OSGI-INF')
        .folder('metatype')
        .file(`${pkgJson.name}.xml`, xml.format(metatype));
    // Add features/metatype.json file
    const metatypeJson = {};
    if (systemConfigJson.category) {
        metatypeJson['category'] = systemConfigJson.category;
    }
    zip.folder('features').file('metatype.json', JSON.stringify(metatypeJson, null, 2));
}
/**
 * Add the portlet preferences file if configured.
 */
function addConfigurationJsonPortletInstanceFile(zip) {
    const portletInstanceConfigJson = getConfigurationJsonPortletInstanceJson();
    if (!portletInstanceConfigJson) {
        return;
    }
    const ddmJson = ddm.transformPreferences(config_1.project, portletInstanceConfigJson);
    zip.folder('features').file('portlet_preferences.json', JSON.stringify(ddmJson, null, 2));
}
/**
 * Get the minimum extender version needed for the capabilities of this bundle
 * to work
 *
 * @return a version number or undefined if none is required
 */
function getMinimumExtenderVersion() {
    const requireJsExtender = config_1.project.jar.requireJsExtender;
    if (typeof requireJsExtender === 'string') {
        if (requireJsExtender === 'any') {
            return undefined;
        }
        return requireJsExtender;
    }
    let minExtenderMinorVersion = 0;
    if (getConfigurationJsonSystemJson()) {
        minExtenderMinorVersion = Math.max(minExtenderMinorVersion, 1);
    }
    if (getConfigurationJsonPortletInstanceJson()) {
        minExtenderMinorVersion = Math.max(minExtenderMinorVersion, 1);
    }
    return `1.${minExtenderMinorVersion}.0`;
}
/**
 * Get portlet instance configuration JSON object from getConfigurationFile()
 * file.
 */
function getConfigurationJsonPortletInstanceJson() {
    if (!config_1.project.jar.configurationFile) {
        return undefined;
    }
    const filePath = config_1.project.jar.configurationFile.asNative;
    const configurationJson = fs_extra_1.default.readJSONSync(filePath);
    if (!configurationJson.portletInstance ||
        !configurationJson.portletInstance.fields ||
        Object.keys(configurationJson.portletInstance.fields).length === 0) {
        return undefined;
    }
    return configurationJson.portletInstance;
}
/**
 * Get system configuration JSON object from getConfigurationFile() file.
 * @return {object}
 */
function getConfigurationJsonSystemJson() {
    if (!config_1.project.jar.configurationFile) {
        return undefined;
    }
    const filePath = config_1.project.jar.configurationFile.asNative;
    const configurationJson = fs_extra_1.default.readJSONSync(filePath);
    if (!configurationJson.system ||
        !configurationJson.system.fields ||
        Object.keys(configurationJson.system.fields).length === 0) {
        return undefined;
    }
    return configurationJson.system;
}
