"use strict";
/**
 * SPDX-FileCopyrightText: © 2017 Liferay, Inc. <https://liferay.com>
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.format = exports.createMetatype = exports.addMetatypeLocalization = exports.addMetatypeAttr = void 0;
const xml_js_1 = require("xml-js");
const TYPES = {
    boolean: 'Boolean',
    float: 'Double',
    number: 'Integer',
    password: 'Password',
    string: 'String',
};
/**
 * Add a metatype AD node to the XML
 */
function addMetatypeAttr(metatype, id, desc) {
    const metadata = findChild(metatype, 'metatype:MetaData');
    const ocd = findChild(metadata, 'OCD');
    const ad = addChild(ocd, 'AD');
    addAttr(ad, 'id', id);
    addAttr(ad, 'type', TYPES[desc.type]);
    addAttr(ad, 'name', desc.name || id);
    if (desc.description !== undefined) {
        addAttr(ad, 'description', desc.description);
    }
    addAttr(ad, 'cardinality', desc.repeatable ? -32767 : 0);
    if (desc.required !== undefined) {
        addAttr(ad, 'required', desc.required);
    }
    if (desc.default !== undefined) {
        addAttr(ad, 'default', desc.default);
    }
    if (desc.options) {
        Object.entries(desc.options).forEach(([value, label]) => {
            const option = addChild(ad, 'Option');
            addAttr(option, 'label', label);
            addAttr(option, 'value', value);
        });
    }
}
exports.addMetatypeAttr = addMetatypeAttr;
function addMetatypeLocalization(xml, localization) {
    const metadata = findChild(xml, 'metatype:MetaData');
    addAttr(metadata, 'localization', localization);
}
exports.addMetatypeLocalization = addMetatypeLocalization;
/**
 * @param id id of configuration
 * @param name human readable name of configuration
 */
function createMetatype(id, name) {
    return xml_js_1.xml2js(`<?xml version="1.0" encoding="UTF-8"?>
<metatype:MetaData xmlns:metatype="http://www.osgi.org/xmlns/metatype/v1.1.0">
	<OCD name="${name}" id="${id}"/>
	<Designate pid="${id}">
		<Object ocdref="${id}"/>
	</Designate>
</metatype:MetaData>`);
}
exports.createMetatype = createMetatype;
/**
 * Format an XML object and return it as a string.
 */
function format(xml) {
    return xml_js_1.js2xml(xml, { spaces: 2 });
}
exports.format = format;
/**
 * Add an attribute to an XML node.
 */
function addAttr(node, name, value) {
    node.attributes = node.attributes || {};
    node.attributes[name] = value;
}
/**
 * Add a child node to an existing node.
 */
function addChild(parentNode, childName) {
    const childNode = {
        attributes: {},
        elements: [],
        name: childName,
        type: 'element',
    };
    parentNode.elements = parentNode.elements || [];
    parentNode.elements.push(childNode);
    return childNode;
}
/**
 * Find an XML child node creating it if necessary.
 */
function findChild(parentNode, childName, create = false) {
    const elements = parentNode.elements || [];
    let childNode = elements.find((node) => node.name === childName);
    if (childNode === undefined && create) {
        childNode = {
            attributes: {},
            elements: [],
            name: childName,
            type: 'element',
        };
        parentNode.elements = elements;
        parentNode.elements.push(childNode);
    }
    return childNode;
}
